****************
dummy_wx
****************

This module does nothing, but is useful when trying to build documentation
for modules that require wxPython.

Do NOT install this module if you already have wxPython installed, as it uses
the same "wx" package name to pretend to be wxPython.

.. start shields 

.. list-table::
	:stub-columns: 1
	:widths: 10 90

	* - Docs
	  - |docs|
	* - Tests
	  - |travis| |requires| |coveralls| |codefactor|
	* - PyPI
	  - |pypi-version| |supported-versions| |supported-implementations| |wheel|
	* - Other
	  - |license| |language| |commits-since| |commits-latest| |maintained| 
	
.. |docs| image:: https://readthedocs.org/projects/dummy_wx/badge/?version=latest
	:target: https://dummy_wx.readthedocs.io/en/latest/?badge=latest
	:alt: Documentation Status

.. |travis| image:: https://img.shields.io/travis/com/domdfcoding/dummy_wx/master?logo=travis
	:target: https://travis-ci.com/domdfcoding/dummy_wx
	:alt: Travis Build Status
	
.. |requires| image:: https://requires.io/github/domdfcoding/dummy_wx/requirements.svg?branch=master
	:target: https://requires.io/github/domdfcoding/dummy_wx/requirements/?branch=master
	:alt: Requirements Status

.. |coveralls| image:: https://coveralls.io/repos/github/domdfcoding/dummy_wx/badge.svg?branch=master
	:target: https://coveralls.io/github/domdfcoding/dummy_wx?branch=master
	:alt: Coverage

.. |codefactor| image:: https://img.shields.io/codefactor/grade/github/domdfcoding/dummy_wx
	:target: https://www.codefactor.io/repository/github/domdfcoding/dummy_wx
	:alt: CodeFactor Grade

.. |pypi-version| image:: https://img.shields.io/pypi/v/dummy_wx.svg
	:target: https://pypi.org/project/dummy_wx/
	:alt: PyPI - Package Version

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/dummy_wx.svg
	:target: https://pypi.org/project/dummy_wx/
	:alt: PyPI - Supported Python Versions

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/dummy_wx
	:target: https://pypi.org/project/dummy_wx/
	:alt: PyPI - Supported Implementations

.. |wheel| image:: https://img.shields.io/pypi/wheel/dummy_wx
	:target: https://pypi.org/project/dummy_wx/
	:alt: PyPI - Wheel

.. |license| image:: https://img.shields.io/github/license/domdfcoding/dummy_wx
	:alt: License
	:target: https://github.com/domdfcoding/dummy_wx/blob/master/LICENSE

.. |language| image:: https://img.shields.io/github/languages/top/domdfcoding/dummy_wx
	:alt: GitHub top language

.. |commits-since| image:: https://img.shields.io/github/commits-since/domdfcoding/dummy_wx/v0.2.5
	:target: https://github.com/domdfcoding/dummy_wx/pulse
	:alt: GitHub commits since tagged version

.. |commits-latest| image:: https://img.shields.io/github/last-commit/domdfcoding/dummy_wx
	:target: https://github.com/domdfcoding/dummy_wx/commit/master
	:alt: GitHub last commit

.. |maintained| image:: https://img.shields.io/maintenance/yes/2020
	:alt: Maintenance

.. end shields